@@ -528,7 +528,7 @@ class Client:
         total,
     ):
         """
-        Creates the dict response of the client to an export_batch() call.
+        Creates the dict response of the client to an export_batch() or export() call.
         :param response: The response received from the rest-api.
         :param total: total messages in batch.
         :return: A dict with response details (see export_batch docs for format).
@@ -537,12 +537,23 @@ class Client:
         failed = 0
         failure_reasons = {}
 
-        # Check if some messages didn't passed validation on the rest-api.
+        # Check if some/all messages didn't passed validation on the rest-api.
         if total > 0 and not response.ok:
             try:
                 result_info = response.json()
-                failed = result_info["failed"]
-                failure_reasons = result_info["failure_reasons"]
+                # TODO (michal): Canonize incoming server responses.
+                # Check for topLevelError in the response (returned when the request
+                # fails for bad arguments).
+                top_level_error = result_info.get("topLevelError")
+                if top_level_error:
+                    failure_reasons = top_level_error
+                    failed = total
+
+                # Other bad responses should have the following keys.
+                else:
+                    failed = result_info["failed"]
+                    failure_reasons = result_info["failure_reasons"]
+
             except Exception:
                 failed = total
                 failure_reasons = "Failed to send the batch to Mona's servers"
@@ -804,7 +815,7 @@ class Client:
         app_server_response = app_server_response.get("response_data")
 
         return (
-            self._handle_service_error(json.dumps(app_server_response.get('issues')))
+            self._handle_service_error(json.dumps(app_server_response.get("issues")))
             if app_server_response and "issues" in app_server_response
             else get_dict_result(True, app_server_response, None)
         )
@@ -838,7 +849,7 @@ class Client:
             return self._handle_service_error(error_message)
 
         return (
-            self._handle_service_error(json.dumps(app_server_response.get('issues')))
+            self._handle_service_error(json.dumps(app_server_response.get("issues")))
             if app_server_response and "issues" in app_server_response
             else get_dict_result(True, app_server_response, None)
         )
@@ -1025,6 +1036,24 @@ class Client:
             else get_dict_result(True, app_server_response["response_data"], None)
         )
 
+    @Decorators.refresh_token_if_needed
+    def create_openai_context_class(self, context_class, openai_api_type):
+        """
+        A wrapper function for "Create new openAI context class" REST endpoint. View
+        full documentation here:
+        https://docs.monalabs.io/docs/create-new-openai-context-class-via-rest-api
+        """
+        app_server_response = self._app_server_request(
+            "create_openai_context_class",
+            data={"context_class": context_class, "openai_api_type": openai_api_type},
+        )
+
+        return (
+            app_server_response
+            if "error_message" in app_server_response
+            else get_dict_result(True, app_server_response["response_data"], None)
+        )
+
     def _handle_service_error(self, error_message):
         """
         Logs an error and raises MonaServiceException if RAISE_SERVICE_EXCEPTIONS is
